## START: Set by rpmautospec
## (rpmautospec version 0.7.2)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global upstreamname hipFFT
%global rocm_release 6.2
%global rocm_patch 0
%global rocm_version %{rocm_release}.%{rocm_patch}

%global toolchain rocm
# hipcc does not support some clang flags
%global build_cxxflags %(echo %{optflags} | sed -e 's/-fstack-protector-strong/-Xarch_host -fstack-protector-strong/' -e 's/-fcf-protection/-Xarch_host -fcf-protection/')

# $gpu will be evaluated in the loops below
%global _vpath_builddir %{_vendor}-%{_target_os}-build-${gpu}

# Only good for testing with a local gpu
# Need to
# export QA_RPATHS=0xff
%bcond_with test

Name:           hipfft
Version:        %{rocm_version}
Release:        %autorelease
Summary:        ROCm FFT marshalling library
Url:            https://github.com/ROCm/%{upstreamname}
License:        MIT

# Only x86_64 works right now
ExclusiveArch:  x86_64

Source0:        %{url}/archive/rocm-%{version}.tar.gz#/%{upstreamname}-rocm-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja-build
BuildRequires:  rocm-cmake
BuildRequires:  rocm-comgr-devel
BuildRequires:  rocm-hip-devel
BuildRequires:  rocm-runtime-devel
BuildRequires:  rocm-rpm-macros
BuildRequires:  rocprim-devel
BuildRequires:  rocfft-devel

%if %{with test}
BuildRequires:  boost-devel
BuildRequires:  fftw-devel
BuildRequires:  gtest-devel
BuildRequires:  hiprand-devel
BuildRequires:  libomp-devel
BuildRequires:  rocrand-devel
%endif

%description
hipFFT is an FFT marshalling library. Currently, hipFFT supports
the rocFFT backends

hipFFT exports an interface that does not require the client to
change, regardless of the chosen backend. It sits between the
application and the backend FFT library, marshalling inputs into
the backend and results back to the application.

%package devel
Summary:        Libraries and headers for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx90a%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx942%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx1100%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx1103%{?_isa} = %{version}-%{release}

%description devel
%{summary}

%if %{with test}
%package test
Summary:        Tests for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description test
%{summary}
%endif

%package gfx90a
Summary:        %{name} for MI200
%description gfx90a
%{summary}

%package gfx942
Summary:        %{name} for MI300
%description gfx942
%{summary}

%package gfx1100
Summary:        %{name} for W7900
%description gfx1100
%{summary}

%package gfx1103
Summary:        %{name} for gfx1103 (experimental)
%description gfx1103
%{summary}

%prep
%autosetup -n %{upstreamname}-rocm-%{version} -p 1

%build
for gpu in %{rocm_gpu_list}
do
    module load rocm/$gpu

    %cmake -G Ninja \
	   -DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=OFF \
	   -DAMDGPU_TARGETS=${ROCM_GPUS} \
	   -DCMAKE_INSTALL_LIBDIR=$ROCM_LIB \
	   -DCMAKE_INSTALL_BINDIR=$ROCM_BIN \
%if %{with test}
           -DBUILD_CLIENTS_TESTS=ON \
%endif
	   -DROCM_SYMLINK_LIBS=OFF \
           -DHIP_PLATFORM=amd \
           -DCMAKE_BUILD_TYPE=RelWithDebInfo

    %cmake_build
    module purge
done

%install
for gpu in %{rocm_gpu_list}
do
    %cmake_install
done

%files
%license LICENSE.md
%exclude %{_docdir}/%{name}/LICENSE.md
%{_libdir}/lib%{name}.so.*
%{_libdir}/rocm/gfx{8,9,10,11}/lib/lib%{name}.so.*

%files gfx90a
%{_libdir}/rocm/gfx90a/lib/lib%{name}.so.*

%files gfx942
%{_libdir}/rocm/gfx942/lib/lib%{name}.so.*

%files gfx1100
%{_libdir}/rocm/gfx1100/lib/lib%{name}.so.*

%files gfx1103
%{_libdir}/rocm/gfx1103/lib/lib%{name}.so.*

%files devel
%dir %{_libdir}/cmake/%{name}
%dir %{_libdir}/rocm/gfx*/lib/cmake/%{name}

%doc README.md
%{_includedir}/%{name}
%{_libdir}/cmake/%{name}/*.cmake
%{_libdir}/lib%{name}.so
%{_libdir}/rocm/gfx*/lib/cmake/%{name}/*.cmake
%{_libdir}/rocm/gfx*/lib/lib%{name}.so


%if %{with test}
%files test
%{_bindir}/hipfft-test
%{_libdir}/rocm/gfx*/bin/hipfft-test
%endif

%changelog
## START: Generated by rpmautospec
* Sun Aug 11 2024 Tom Rix <Tom.Rix@amd.com> - 6.2.0-1
- Update to ROCm 6.2

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 6.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue May 21 2024 Tom Rix <trix@redhat.com> - 6.1.1-1
- Update to 6.1.1

* Mon Mar 11 2024 Tom Rix <trix@redhat.com> - 6.0.0.18c75d8-2
- Update for llvm17

* Thu Jan 25 2024 Tom Rix <trix@redhat.com> - 6.0.0.18c75d8-1
- Initial package
## END: Generated by rpmautospec
